============
Installation
============

At the command line::

    $ easy_install seedmeopenmm

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv seedmeopenmm
    $ pip install seedmeopenmm
